@@ -6,8 +6,10 @@
 // along with cmark-syntax.  If not, see <http://www.gnu.org/licenses/>
 mod javascript;
 mod rust;
+mod sh;
 mod toml;
 
 pub use javascript::JavaScript;
 pub use rust::Rust;
+pub use sh::Sh;
 pub use toml::Toml;
